/*
This file is a part of the MSS project.
Copyright (C) 2008  Giovani Manzeppi Faccin

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public
License as published by the Free Software Foundation; either
version 3.0 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public
License along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

Giovani Manzeppi Faccin (giovanifaccin@yahoo.com.br)
*/
#ifndef STDATOM_H
#define STDATOM_H
#include <cmath>
#include "Point.h"
#include "Enumerable_Object.h"
/**
*This class is a container that holds all data regarding a single classical atom.
*\Author: Giovani Manzeppi Faccin, 24/02/2008.
*\par By default the units used are nm (nanometers), nm/fs (nanometers / femtoseconds) and nm/fs**2.
*/

class Atom_Classical : public Enumerable_Object
{
public:
    Atom_Classical();
    ~Atom_Classical();
	////////////////////////////////////////////////////////////////////////////////////////////////////////
	//Functions to access the atom's data.
	//!Sets the atom's current X coordinate, in nm.
	void set_x(double xin){data_double[0] = xin;};
	//!Returns the atom's X position.
	double x(){return data_double[0];};
	//!Returns the atom's position point.
	Point posi();

	//!Copy operator.
	Atom_Classical& operator=(Atom_Classical&);

private:
	static double const mass[];
	
	static const unsigned short data_double_size = 15;
	double data_double[data_double_size];
	//data_double correspondence table:
	//data_double[0] = x;
	//data_double[1] = y;
	//data_double[2] = z;
	//data_double[3] = vx;
	//data_double[4] = vy;
	//data_double[5] = vz;
	//data_double[6] = fx;
	//data_double[7] = fy;
	//data_double[8] = fz;
	//data_double[9] = x0;
	//data_double[10] = y0;
	//data_double[11] = z0;
	//data_double[12] = potential energy;
	//data_double[13] = total spin up;
	//data_double[14] = total spin down;

	static const unsigned short data_unsigned_short_size = 1;
	unsigned short data_unsigned_short[data_unsigned_short_size];
	//data_unsigned_short correspondence table:
	//data_unsigned_short[0] = element of periodic table;
		
};
#endif
