/*
This file is a part of the MSS project.
Copyright (C) 2008  Giovani Manzeppi Faccin

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public
License as published by the Free Software Foundation; either
version 3.0 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public
License along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

Giovani Manzeppi Faccin (giovanifaccin@yahoo.com.br)
*/
#include "Box.h"

//!The class default constructor sets up an infinite box.
Box::Box()
{
	data[0] = data[1] = data[2] = -9999999.0;
	data[3] = data[4] = data[5] = 999999.0;
	update_box_data();
}

//!This constructor receives the box size already at startup. The first argument is the l point, and the second, the h point.
Box::Box(Point *a, Point *b)
{
	set_size(&(*a), &(*b));
}

Box::~Box()
{
}

//Overloading the = operator.
Box& Box::operator=(Box& other)
{
	//Copying internal data:
	unsigned short bla = data_size;
	do
	{
		bla--;
		data[bla] = other.data[bla];
	}while(bla);
	return *this;
} 

//!Operator overload. The '<<' operator returns a string containing this objects's data in a way ready to be used with cout.
std::ostream &operator<<( std::ostream &output, const Box &b )
{
	output << "x = [" << b.data[0] << "," << b.data[3] << "] y = [" << b.data[1] << "," << b.data[4] << "] z = [" << b.data[2] << "," << b.data[5] << "] center = [" << b.data[9] << "," << b.data[10] << "," << b.data[11] << "]";
	return output;
}

//!Sets the box size. The first argument is the l point, and the second, the h point.
void Box::set_size(Point *a, Point *b)
{
	data[0] = a->x();
	data[1] = a->y();
	data[2] = a->z();
	data[3] = b->x();
	data[4] = b->y();
	data[5] = b->z();
	update_box_data();
}

//!Sets the box size. The arguments are: lx, ly, lz, hx, hy, hz.
void Box::set_size(double lx, double ly, double lz, double hx, double hy, double hz)
{
	data[0] = lx;
	data[1] = ly;
	data[2] = lz;
	data[3] = hx;
	data[4] = hy;
	data[5] = hz;
	update_box_data();
}

//!Updates the box internal data when something has changed, and checks for possible errors.
void Box::update_box_data()
{
	//Updating lengths:
	data[6] = data[3] - data[0];
	data[7] = data[4] - data[1];
	data[8] = data[5] - data[2];
	//Updating the center:
	data[9] = data[6] * 0.5 + data[0];
	data[10] = data[7] * 0.5 + data[1];
	data[11] = data[8] * 0.5 + data[2];
}
