/*
This file is a part of the MSS project.
Copyright (C) 2008  Giovani Manzeppi Faccin

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public
License as published by the Free Software Foundation; either
version 3.0 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public
License along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

Giovani Manzeppi Faccin (giovanifaccin@yahoo.com.br)
*/
#ifndef ENUMERABLE_OBJECT_H_
#define ENUMERABLE_OBJECT_H_
/* Base class that should de inherited by classes that instantiate objects that have these characteristics:
 * - Each object has an unique id.
 * - Each object 'belongs' to another object that also has a unique id.
 * 
 * Notice that the data container is private; and thus accessible only through use of the base class's methods.
 * */
class Enumerable_Object
{
public:
	Enumerable_Object();
	virtual ~Enumerable_Object();
	
	//!Sets this object's id. This value must be unique for each other object of this class in the entire simulation.
	void set_id(unsigned long id_in){data[0] = id_in;};
	//!Returns the atom's id number.
	unsigned long id(){return data[0];};
	//!Sets this object's parent's id.
	void set_belongs_to(unsigned long id2_in){data[1] = id2_in;};
	//!Returns the atom's id number.
	unsigned long belongs_to(){return data[1];};

	//Make a copy operator.
	Enumerable_Object& operator=(Enumerable_Object&);
	//!Is equal to operator.
	bool operator==(Enumerable_Object&);
	//!Is not equal to operator.
	bool operator!=(Enumerable_Object&);
	
private:
	//Size of data vector:
	static const unsigned short data_size = 2;
	
	unsigned long data[data_size];
	//The data table is below:
	//data[0] = id
	//data[1] = belongs_to_id	
};

#endif /*ENUMERABLE_OBJECT_H_*/
