/*
This file is a part of the MSS project.
Copyright (C) 2008  Giovani Manzeppi Faccin

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public
License as published by the Free Software Foundation; either
version 3.0 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public
License along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

Giovani Manzeppi Faccin (giovanifaccin@yahoo.com.br)
*/
#ifndef POINT_H_
#define POINT_H_
#include <cmath>
#include <iostream>

/*! Defines a point in 3D space.
 * \author Giovani Manzeppi Faccin 24/02/2008.
 * */
class Point
{
public:
	//!Default constructor does nothing.
	Point();
	//!Optional constructor set's up the container data.
	Point(double, double, double);
	//!Default destructor.
	virtual ~Point();
	//!Operator overload. The '=' operator copies the contents of one point to the other.
	Point& operator=(Point&);
	//!Operator overload. The '<<' operator returns a string containing this pointer's data in a way ready to be used with cout.
	friend std::ostream &operator<<( std::ostream &, const Point & );
	//!Returns this point's X coordinate.
	double x(){return data[0];};
	//!Returns this point's Y coordinate.
	double y(){return data[1];};
	//!Returns this point's Z coordinate.
	double z(){return data[2];};
	//!Defines this point's X coordinate.
	void set_x(double in){data[0] = in;};
	//!Defines this point's Y coordinate.
	void set_y(double in){data[1] = in;};
	//!Defines this point's Z coordinate.
	void set_z(double in){data[2] = in;};

private:
	static const unsigned short data_size = 3;
	double data[data_size];
	//Data correspondence table:
	//data[0] = x;
	//data[1] = y;
	//data[2] = z;	
};

#endif /*POINT_H_*/
