/*
This file is a part of the MSS project.
Copyright (C) 2008  Giovani Manzeppi Faccin

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public
License as published by the Free Software Foundation; either
version 3.0 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public
License along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

Giovani Manzeppi Faccin (giovanifaccin@yahoo.com.br)
*/
#ifndef POTENTIAL_H_
#define POTENTIAL_H_
#include "Atom_Classical.h"
#include <list>
#include "Box.h"
//!Abstract class. Defines common data and members for it's derived classes.
class Potential
{
public:
	Potential();
	virtual ~Potential();
	
	//!The first argument is the atom whose force we wish to evaluate. The second is a list with all atoms that it interacts with.
	virtual Point calc_atom_forc(Atom_Classical*, std::list<Atom_Classical*>* )=0;
	//!Returns the distance between two points in the X direction, considering periodic boundary conditions.
	double distance_x(Point*, Point*);
	//!Returns the distance between two points in the Y direction, considering periodic boundary conditions.
	double distance_y(Point*, Point*);
	//!Returns the distance between two points in the Z direction, considering periodic boundary conditions.
	double distance_z(Point*, Point*);
	//!Defines the simulation box for this potential. This is the same box for all potentials, which are all linked the real box instantiated at by te Grid object.
	void set_simulation_box(Box *sm){simulation_box = &(*sm);};
	
protected:
	Box *simulation_box;
};

#endif /*POTENTIAL_H_*/

