/*
This file is a part of the MSS project.
Copyright (C) 2008  Giovani Manzeppi Faccin

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public
License as published by the Free Software Foundation; either
version 3.0 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public
License along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

Giovani Manzeppi Faccin (giovanifaccin@yahoo.com.br)
*/
#include "Potential_Openmx.h"

Potential_Openmx::Potential_Openmx()
{
}

Potential_Openmx::~Potential_Openmx()
{
}

Point Potential_Openmx::calc_atom_forc(Atom_Classical *atm, std::list<Atom_Classical*> *neighbours)
{
	std::vector<Atom_Classical> changed_atms;
	double bd_x, sd_x; //bd = distance considering boundary conditions, st = straight distance, without boundary conditions
	bool must_update_x;
	Point a = atm->posi();

    for ( std::list<Atom_Classical*>::iterator a = neighbours->begin(); a != neighbours->end(); a++)
    {
    	//Notice that upon printing the first guy we'll get a weird number instead of '5'. The others will come out right:
    	cout << (*a)->id() << endl;
    };	
	
    
	//Looping over the neighbours list, and if necessary, creating new atoms with updated locations:
	for (std::list<Atom_Classical*>::iterator neigh = neighbours->begin(); neigh != neighbours->end(); neigh++)
	{	
		Point b = (*neigh)->posi();
		bd_x = distance_x( &(a), &(b) );
		sd_x = a.x() - b.x();
		
		must_update_x = false;
		//If we happen to have a periodic boundary condition in direction x:
		if ( fabs(sd_x) > fabs(bd_x) )
			must_update_x = true;
		
		//If needed, we'll make the necessary updates now. These consist of copying the original atom
		//pointed at the neighbours list into the changed_atoms vector. Then we update the changed_atoms with the
		//correct locations, and make the neighbours pointer point to the changed_atoms guy instead of the original one.
		if ( must_update_x )
		{
			changed_atms.push_back( *(*neigh) );
			if ( must_update_x )
			{
				if ( a.x() < b.x() )
					changed_atms[changed_atms.size() -1].set_x( changed_atms[changed_atms.size() -1].x() - simulation_box->length_x() );	
				else
					changed_atms[changed_atms.size() -1].set_x( changed_atms[changed_atms.size() -1].x() + simulation_box->length_x() );
			};
			
			//Notice that this cout prints what is expected to be printed.
			cout << "Before changing atom " << (*neigh)->id() << " we had: " << (*neigh)->x() << "  ";
			
			//Now we'll make the corresponding neigh pointer point to the changed atom, instead of the atom in the original list:
			(*neigh) = &(changed_atms[changed_atms.size() -1]);
			
			//Notice that this cout prints what is expected to be printed.
			cout << "now we have " << (*neigh)->x() << endl;
		};
	};

	//This is the Code that will crash:	
    for ( std::list<Atom_Classical*>::iterator a = neighbours->begin(); a != neighbours->end(); a++)
    {
    	//Notice that upon printing the first guy we'll get a weird number instead of '5'. The others will come out right:
    	cout << (*a)->id() << endl;
    };
    
    //This is just to give the function a return value:
    Point frc(1,1,1);
	return frc;
}
